/* pi.h
Copyright (c) 2014 by Michael Zahniser

Endless Sky is free software: you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later version.

Endless Sky is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef PI_H_
#define PI_H_



// Constants to replace M_PI (which is not available on all operating systems).
constexpr double PI = 3.14159265358979323846;
constexpr double TO_RAD = PI / 180.;
constexpr double TO_DEG = 180. / PI;



#endif
